@@ -333,8 +333,13 @@ def userInGroup(userName, groupName):
 
 	return False
 
+def syncgroup(group, hubname = "", purgeorphans = True, addgroupmemberships = True):
+	_syncgroups(hubname,purgeorphans,addgroupmemberships,group)
 
 def syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True):
+    _syncgroups(hubname,purgeorphans,addgroupmemberships,'*')
+
+def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, group = '*'):
 	
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -349,7 +354,11 @@ def syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True):
 	if purgeorphans:
 
 		# store of all gids from the DB and store them off for easy lookup
-		sql = "SELECT `cn` from jos_xgroups"
+		if group == '*':
+		    sql = "SELECT `cn` from jos_xgroups"
+		else:
+		    sql = "SELECT `cn` from jos_xgroups WHERE cn='" + group + "'"
+
 		groupsFromDB = {}
 		for group in db.query(sql, None):
 			groupsFromDB[group.cn] = 1
@@ -359,7 +368,10 @@ def syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True):
 
 		# get all groups from ldap
 		try:
-			r = l.search_s("ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn'])
+			if group == '*':
+			    r = l.search_s("ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn'])
+            else:
+            	r = l.search_s("cn="+group+"ou=groups," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixGroup)',   ['cn']) 
 
 		except ldap.NO_SUCH_OBJECT:
 			print "No groups found"
@@ -374,8 +386,11 @@ def syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True):
 	
 
 	# grab complete informaton on all groups from db 
-	sql = "SELECT `cn`, `description`, `gidNumber` from jos_xgroups"
-	
+	if group == '*'
+	    sql = "SELECT `cn`, `description`, `gidNumber` from jos_xgroups"
+	else:
+	    sql = "SELECT `cn`, `description`, `gidNumber` from jos_xgroups WHERE cn='" + group + "'"
+
 	for group in db.query(sql, None):
 	
 		if not group.description: group.description = ""
