@@ -590,7 +590,7 @@ def getLDAPMinUIDNumber(hubname = "", minUIDNumber=1, maxUIDNumber=1000):
 	return rv
 
 
-def syncUser(username, hubname = "", syncAttributes = False):
+def _syncuser(username, hubname = "", syncAttributes = False):
 	"""
 	sync attributes syncs all available non essential account attributes.
 	"""
@@ -641,7 +641,7 @@ def syncUser(username, hubname = "", syncAttributes = False):
 		               hubname,
 		               attrsToSync)
 	else:
-		print "syncuser cannot find info on username: " + username + " from the jos_users table"
+		print "_syncuser cannot find info on username: " + username + " from the jos_users table"
 		
 
 		
@@ -707,7 +707,13 @@ def add_ldap_user2(cn,
 		#	traceback.print_exc()
 		
 
+def syncuser(user, hubname = "", purgeorphans = True, syncattributes = True, user = '*'):
+     _syncusers(hubname, purgeorphans, syncattributes, user)
+
 def syncusers(hubname = "", purgeorphans = True, syncattributes = True):
+     _syncusers(hubname, purgeorphans, syncattributes, '*')
+
+def _syncusers(hubname = "", purgeorphans = True, syncattributes = True, user = '*'):
 	
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword()
 	dbUserName = hubzero.config.webconfig.getWebConfigDBUsername()
@@ -722,7 +728,11 @@ def syncusers(hubname = "", purgeorphans = True, syncattributes = True):
 		print "Orphaned users in ldap without a corresponding group in the database will be DELETED"
 
 		# grab all users from db and store them off for easy lookup
-		sql = "SELECT `username` from jos_xprofiles"
+		if user == '*':
+		    sql = "SELECT `username` from jos_xprofiles"
+		else:
+			sql = "SELECT `username` from jos_xprofiles WHERE username='" + user + "'"
+
 		usersFromDB = {}
 		for user in db.query(sql, None):
 			usersFromDB[user.username] = 1
@@ -737,7 +747,10 @@ def syncusers(hubname = "", purgeorphans = True, syncattributes = True):
 		l = ldap.initialize(ldapServer)
 		l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
-		r = l.search_s("ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+        if user == '*':
+		    r = l.search_s("ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
+		else:
+			r = l.search_s("uid="+user+"ou=users," + siteSuffix, ldap.SCOPE_SUBTREE, '(objectClass=posixAccount)', ['uid'])
 
 		for dn,entry in r:
 			uid = str(entry['uid'][0])
@@ -750,9 +763,12 @@ def syncusers(hubname = "", purgeorphans = True, syncattributes = True):
 					print " user not found"
 
 	# now do a mass add of all users from db	
-	sql = "SELECT `username`, `name`, `userPassword`, `uidNumber`, `homeDirectory`, `loginShell`, `gid`, gidNumber from jos_xprofiles"
+	if user == '*':
+	    sql = "SELECT `username`, `name`, `userPassword`, `uidNumber`, `homeDirectory`, `loginShell`, `gid`, gidNumber from jos_xprofiles"
+	else:
+		sql = "SELECT `username`, `name`, `userPassword`, `uidNumber`, `homeDirectory`, `loginShell`, `gid`, gidNumber from jos_xprofiles WHERE username='" + user + "'"
 	
 	for user in db.query(sql, None):
 		print "syncing user:" + user.username
-		syncUser(user.username, hubname, syncattributes)
+		_syncuser(user.username, hubname, syncattributes)
 	
\ No newline at end of file
